#
# spec file for package python-jwcrypto
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}

%define skip_python2 1

Name:           python-jwcrypto
Version:        1.4.2
Release:        1.5
Summary:        Python module package implementing JOSE Web standards
License:        LGPL-3.0-only
URL:            https://github.com/latchset/jwcrypto
Source:         https://files.pythonhosted.org/packages/source/j/jwcrypto/jwcrypto-%{version}.tar.gz
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module cryptography >= 2.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Deprecated
Requires:       python-cryptography >= 2.3
BuildArch:      noarch
%python_subpackages

%description
A Python implementation of the JOSE Working Group documents:
RFC 7515 - JSON Web Signature (JWS)
RFC 7516 - JSON Web Encryption (JWE)
RFC 7517 - JSON Web Key (JWK)
RFC 7518 - JSON Web Algorithms (JWA)
RFC 7519 - JSON Web Token (JWT)
RFC 7520 - Examples of Protecting Content Using JSON Object Signing and Encryption (JOSE)

%prep
%setup -q -n jwcrypto-%{version}

%build
%python_build

%install
%python_install
rm -rv %{buildroot}%{_datadir}/doc/jwcrypto
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest jwcrypto

%files %{python_files}
%{python_sitelib}/*
%license LICENSE
%doc README.md

%changelog
* Fri Nov 18 2022 Michael Ströder <michael@stroeder.com>
- update to 1.4.2 which also fixes CVE-2022-3102
  too many other changes to be listed here
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, not required
* Thu Aug  5 2021 Michael Ströder <michael@stroeder.com>
- update to 1.0
  * Create SECURITY.md
  * Allow empty payloads in JWS tokens
  * Add tests to check empty payload support
  * Drop python2 compatibility
  * Fix python3 pylint issues
  * Add explicit support to check 'typ' in JWT
  * Drop support for importing old MutableMapping
  * Disable annoying pep8 naming checks
* Sat Jun 12 2021 Michael Ströder <michael@stroeder.com>
- added Requires: python-Deprecated
- update to upstream release 0.9.1
  * Create codeql-analysis.yml
  * Add back ppc64le CI
  * Actually add the split out ppc64le action
  * Silence a test warning
  * Remove the _params abstraction and simplify JWK
  * Fix crash in exception handler
  * Add test for Issue 209
  * Fix keyset import with similar keys
  * Test fix for Issue 208
  * Add __repr__() to mask keys
  * Adding Power support(ppc64le) with ci and testing to the project for architecture independent
  * Added six as a dependency to avoid import error
  * Make sure an empty dict is a valid JWT payload
  * Turn JWK into a dict-like object
  * Go one step further and provide access as attrs
  * Drop support for py34 as it stopped working on F33
  * Deprecate RSA1_5 and remove from defaults
  * Make PBES2 behave like all other algorithms
  * Enforce protected header in compact serilization
  * Fix importing Public EC keys from PEM files
  * Installation instructions + extra badges
  * RFC 8812 - Add Default allowed algorithms
* Sun Sep  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use constraints on the cryptography dependency
* Sun Sep  6 2020 Michael Ströder <michael@stroeder.com>
- update to upstream release 0.8
  * Fix some documentation typos
  * Rename ambiguous variable
  * Remove cap on sphinx version
  * Fix okp key type import
  * Add method to export Keys ans Sets as dictionaries
  * Typo rectified
  * Add secp256k1 curve
* Mon Mar 30 2020 Michael Ströder <michael@stroeder.com>
- update to upstream release 0.7.0
  * Allow to use JWKSet on a JWT with no KID
  * Fixed JWE jose_header
  * Added JWE/JWS custom registry header implementation
  * RFC 8037 - Support for Ed25519, Ed448
  * Stricter OKP key generation parms check
  * Add X25519/X448 support
  * Simplify internal code curve selection
  * Fix encoding length of EC keys Coordinates
  * Add the ability to verify 'none' signatures
  * Import ABC from collections.abc instead of collections for Python 3.9 compatibility
* Fri Mar 22 2019 Michael Ströder <michael@stroeder.com>
- update to upstream release 0.6.0
  * Use python-cryptography's AES key wrapping
  * Add tests for key wrapping where CEK < KEK
  * Fix ECDH-ES key exchange for CEK greater than KEK
  * Add support for RFC7797
  * Fix JWK.from_json
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jun 27 2018 michael@stroeder.com
- update to upstream release 0.5.0:
  * Better validation of JWE
  * Avoid deprecation warnings
  * Tested to work with python 3.7
* Mon Jun 25 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Aug  3 2017 michael@stroeder.com
- update to upstream release 0.4.2
* Mon Jul 24 2017 michael@stroeder.com
- update to upstream release 0.4.1
* Sat Dec  3 2016 michael@stroeder.com
- update to upstream release 0.4.0
* Fri Nov 11 2016 michael@stroeder.com
- initial package of upstream release 0.3.1
